@@ -72,6 +72,7 @@
 ##'   representing the statistics. If \code{transpose = TRUE} then the results
 ##'   have columns for each pollutant-site combination.
 ##' @param ... Other arguments, currently unused.
+##' @import lazyeval
 ##' @export
 ##' @import reshape2
 ##' @author David Carslaw
@@ -80,19 +81,16 @@
 ##'
 ##' ## Statistics for 2004. NOTE! these data are in ppb/ppm so the
 ##' ## example is for illustrative purposes only
-##' aqStats(selectByDate(mydata, year = 2004), pollu=c("no2", "pm10"))
-##' ## transpose the results:
-##' aqStats(selectByDate(mydata, year = 2004), pollu=c("no2", "pm10"),
-##' transpose = TRUE)
+##' aqStats(selectByDate(mydata, year = 2004), pollutant = "no2")
 ##'
 ##'
 aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(95, 99),
                     transpose = FALSE, ...) {
 
     ## get rid of R check annoyances
-    year = site <- NULL; daylight <- NULL
+    year = site <- NULL; daylight <- NULL; . <- NULL
 
-    ## check data and add 'ste' filed if not there
+    ## check data and add 'ste' field if not there
     if (!"site" %in% names(mydata)) mydata$site <- "site"
 
     vars <- c("date", pollutant, "site")
@@ -102,7 +100,7 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
     ## pre-defined lits of pollutants that need special treatment
     thePolls <- c("no2", "o3", "pm10", "co")
 
-    calcStats <- function(mydata, pollutant, percentile, ...) {
+    calcStats <- function(mydata, pollutant, data.thresh, percentile, ...) {
 
         ## file any missing hours
         start.date <- as.POSIXct(dateTrunc(min(mydata$date), "year"))
@@ -113,166 +111,102 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
         all.dates <- data.frame(date = seq(start.date, end.date, by = interval))
         mydata <- merge(mydata, all.dates, all = TRUE)
         mydata$year <- format(mydata$date, "%Y")
+        
+       
+        Mean <- group_by(mydata, year) %>%
+          do(timeAverage(., avg.time = "year", statistic = "mean", data.thresh,
+                         print.int = FALSE)) %>%
+          rename_(mean = pollutant)
+        
+        Min <- group_by(mydata, year) %>%
+          do(timeAverage(., avg.time = "year", statistic = "min", data.thresh,
+                         print.int = FALSE)) %>%
+          rename_(minimum = pollutant)
+        
+        Max <- group_by(mydata, year) %>%
+          do(timeAverage(., avg.time = "year", statistic = "max", data.thresh,
+                         print.int = FALSE)) %>%
+          rename_(maximum = pollutant)
+        
+        maxDaily <- group_by(mydata, year) %>%
+          do(timeAverage(., avg.time = "day", statistic = "mean", data.thresh,
+                         print.int = FALSE)) %>%
+                           do(timeAverage(., avg.time = "year", statistic = "max",
+                                          data.thresh, print.int = FALSE)) %>%
+          rename_(daily.max = pollutant)
+        
+        Median <- group_by(mydata, year) %>%
+          do(timeAverage(., avg.time = "year", statistic = "median", data.thresh)) %>%
+          rename_(median = pollutant)
+        
+        dataCapture <- group_by(mydata, year) %>%
+          do(timeAverage(., avg.time = "year", statistic = "data.cap", data.thresh)) %>%
+          rename_(dat.cap = pollutant)
+        
+        rollMax8 <- group_by(mydata, year) %>%
+          do(rollingMean(., pollutant = pollutant, data.thresh = data.thresh,
+                         width = 8, new.name = pollutant)) %>%
+                           do(timeAverage(., avg.time = "year", statistic = "max", data.thresh)) %>%
+                           rename_(max.roll.8 = pollutant)
+        
+        rollMax24 <- group_by(mydata, year) %>%
+          do(rollingMean(., pollutant = pollutant, data.thresh = data.thresh,
+                         width = 24, new.name = pollutant)) %>%
+                           do(timeAverage(., avg.time = "year", statistic = "max", data.thresh)) %>%
+                           rename_(max.roll.24 = pollutant)
+        
+        Percentile <- group_by(mydata, year) %>%
+          do(calcPercentile(., avg.time = "year", pollutant = pollutant,
+                            data.thresh = data.thresh, percentile = percentile))
 
-        dataCapture <- function(mydata, ...){
-            ## % data capture
-            value <- mydata[ , pollutant]
-            all.hours <- length(value)
-            missing.hours <- sum(is.na(value))
-            data.cap <- round(100 * (all.hours - missing.hours) / all.hours, 1)
-            data.cap
-        }
-
-        daysMoreThan <- function(mydata, threshold, ...) {
-            if (all(is.na(mydata[ , pollutant]))) return(NA)
-            ## identify days where pm10 > limit
-            daily <- timeAverage(mydata, "day", data.thresh)
-            days <- length(which(daily[ , pollutant] > threshold))
-            days
-        }
-
-        ozoneRolling <- function(mydata, threshold, ...) {
-            ## first calculate rolling hourly means
-
-            mydata[, "rolling"] <- .Call("rollingMean", mydata[, pollutant], 8, data.thresh, "right",
-                                         PACKAGE = "openair")
-            daily <- timeAverage(mydata, avg.time = "day", statistic = "max", data.thresh)
-            days <- length(which(daily[ , "rolling"] > threshold))
-            days
-        }
-
-        hoursMoreThan <- function(mydata, threshold = 200, ...) {
-            hours <- length(which(mydata[ , pollutant] > threshold))
-            hours
-        }
-
-        AOT40 <- function(mydata, ...) {
-            ## note the assumption is the O3 is in ug/m3
-
-            ## need daylight hours in growing season (April to September)
-            mydata <- selectByDate(mydata, month = 4:9)
-            mydata <- cutData(mydata, "daylight", ...)
-            mydata <- subset(mydata, daylight == "daylight")
-            AOT40 <- ifelse(mydata[ , pollutant] - 80 < 0 , 0, mydata[ , pollutant] - 80)
-            AOT40 <- sum(AOT40, na.rm = TRUE) * 0.50 ## for ppb
-            AOT40
-        }
-
-        maxDaily <- function(mydata, threshold = 50, ...) {
-            if (all(is.na(mydata[ , pollutant]))) return(NA)
-            maxDaily <- timeAverage(mydata, "day", statistic = "mean", data.thresh)
-            maxDaily <- max(maxDaily[ , pollutant], na.rm = TRUE)
-            maxDaily
-        }
-
-        rollMax <- function(mydata, width = width, ...) {
-            if (all(is.na(mydata[ , pollutant]))) return(NA)
-            ## first calculate rolling hourly means
-
-            mydata[, "rolling"] <- .Call("rollingMean", mydata[, pollutant], width, data.thresh, "right",
-                                         PACKAGE = "openair")
-            rollMax <- max(mydata[ , "rolling"], na.rm = TRUE)
-            rollMax
-        }
-
-        Min.fun <- function(mydata, ...) {
-
-            if (all(is.na(mydata[ , pollutant]))) return(NA)
-            Min <- min(mydata[ , pollutant], na.rm = TRUE)
-            Min
-
-        }
-
-        Max.fun <- function(mydata, ...) {
-
-            if (all(is.na(mydata[ , pollutant]))) return(NA)
-            Max <- max(mydata[ , pollutant], na.rm = TRUE)
-            Max
-
-        }
-
-        Mean.fun <- function(mydata, ...) {
-
-            if (all(is.na(mydata[ , pollutant]))) return(NA)
-            Mean <- mean(mydata[ , pollutant], na.rm = TRUE)
-            Mean
-
-        }
-
-
-
-        Mean <- ddply(mydata[ , c("year", pollutant)], .(year), Mean.fun,
-                      pollutant, ...)
-        names(Mean)[2] <- "mean"
-
-        Min <- ddply(mydata[ , c("year", pollutant)], .(year), Min.fun,
-                     pollutant, ...)
-        names(Min)[2] <- "minimum"
-
-        Max <- ddply(mydata[ , c("year", pollutant)], .(year), Max.fun,
-                     pollutant, ...)
-        names(Max)[2] <- "maximum"
-
-        maxDaily <- ddply(mydata[ , c("date", "year", pollutant)], .(year), maxDaily, ...)
-        names(maxDaily)[2] <- "max.daily"
-
-        Median <- ddply(mydata[ , c("year", pollutant)], .(year), numcolwise(median),
-                        na.rm = TRUE)
-        names(Median)[2] <- "median"
-
-        dataCapture <- ddply(mydata[ , c("year", pollutant)], .(year), dataCapture,
-                             pollutant, ...)
-        names(dataCapture)[2] <- "data.capture"
-
-        rollMax8 <- ddply(mydata[ , c("date", "year", pollutant)], .(year),
-                          rollMax, width = 8, ...)
-        names(rollMax8)[2] <- "max.rolling.8"
-
-        rollMax24 <- ddply(mydata[ , c("date", "year", pollutant)], .(year),
-                           rollMax, width = 24, ...)
-        names(rollMax24)[2] <- "max.rolling.24"
-
-
-        ## use openair function
-        Percentile <- calcPercentile(mydata[ , c("date", pollutant)],
-                                     pollutant = pollutant, data.thresh,
-                                     percentile = percentile, avg.time = "year")
-        names(Percentile)[1] <- "year"
-        Percentile$year <- format(Percentile$year, "%Y")
-
-
-
+        
         if (length(grep("o3", pollutant, ignore.case = TRUE)) == 1) {
-            rollingO3 <- ddply(mydata[ , c("date", "year", pollutant)], .(year),
-                               ozoneRolling, threshold = 100, ...)
-            names(rollingO3)[2] <- "roll.8.O3.gt.100"
+            
+            rollingO3 <- group_by(mydata, year) %>%
+              do(rollingMean(., pollutant, data.thresh = data.thresh)) %>%
+              do(timeAverage(., avg.time = "day", statistic = "max", data.thresh = data.thresh)) %>%
+              summarise_(roll.8.O3.gt.100 = interp(~ length(which(var > 100)), var = as.name("rolling8o3")))
 
-            rollingO3b <- ddply(mydata[ , c("date", "year", pollutant)], .(year),
-                               ozoneRolling, threshold = 120, ...)
-            names(rollingO3b)[2] <- "roll.8.O3.gt.120"
+            rollingO3$site <- Mean$site ## make sure all have same columns
+            rollingO3$date <- Mean$date
 
-            AOT40 <- ddply(mydata[ , c("date", "year", pollutant)], .(year),
-                           AOT40, ...)
-            names(AOT40)[2] <- "AOT40"
+            rollingO3b <- group_by(mydata, year) %>%
+              do(rollingMean(., pollutant, data.thresh = data.thresh)) %>%
+              do(timeAverage(., avg.time = "day", statistic = "max",
+                             data.thresh = data.thresh)) %>%
+                               summarise_(roll.8.O3.gt.120 = interp(~ length(which(var > 120)), var = as.name("rolling8o3")))
+
+            rollingO3b$site <- Mean$site ## make sure all have same columns
+            rollingO3b$date <- Mean$date
+            
+            AOT40 <- group_by(mydata, year) %>%
+              do(AOT40(., pollutant))
+
+            AOT40$site <- Mean$site ## make sure all have same columns
+            AOT40$date <- Mean$date
 
             o3.results <- list(dataCapture, Mean, Min, Max, Median, maxDaily, rollMax8, rollMax24,
                                Percentile, rollingO3, rollingO3b, AOT40)
-            o3.results <- Reduce(function(x, y, by = 'year') merge(x, y, by = 'year',
-                                                all = TRUE), o3.results)
+            o3.results <- Reduce(function(x, y) merge(x, y, by = c('site', 'year', 'date'),
+                                                      all = TRUE), o3.results)
             o3.results$pollutant <- "O3"
             results <- o3.results
             results
         }
 
         if (length(grep("no2", pollutant, ignore.case = TRUE)) == 1) {
-            hours <- ddply(mydata[ , c("year", pollutant)], .(year), hoursMoreThan, threshold = 200,
-                           ...)
-            names(hours)[2] <- "hours.gt.200"
-
-            no2.results <- list(dataCapture, Mean, Min, Max, Median,  maxDaily, rollMax8, rollMax24,
-                                Percentile, hours)
-            no2.results <- Reduce(function(x, y, by = 'year') merge(x, y, by = 'year',
-                                                 all = TRUE), no2.results)
+            
+            hours <- group_by(mydata, year) %>%
+              summarise_(hours = interp(~ length(which(var > 200)),
+                             var = as.name(pollutant)))
+            hours$site <- Mean$site ## make sure all have same columns
+            hours$date <- Mean$date
+            
+            no2.results <- list(dataCapture, Mean, Min, Max, Median,  maxDaily, rollMax8,
+                                rollMax24, Percentile, hours)
+            
+            no2.results <- Reduce(function(x, y) merge(x, y, by = c('site', 'year', 'date'),
+                                                       all = TRUE), no2.results)
 
             no2.results$pollutant <- "NO2"
             results <- no2.results
@@ -280,15 +214,19 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
         }
 
         if (length(grep("pm10", pollutant, ignore.case = TRUE)) == 1) {
-            days <- ddply(mydata[ , c("date", "year", pollutant)], .(year),
-                          daysMoreThan, threshold = 50, ...)
-            names(days)[2] <- "days.gt.50"
 
-            pm10.results <- list(dataCapture, Mean, Min, Max, Median, maxDaily, rollMax8, rollMax24,
-                                 Percentile, days)
+            days <- group_by(mydata, year) %>%
+              do(timeAverage(., avg.time = "day", statistic = "mean", data.thresh)) %>%
+              summarise_(days = interp(~ length(which(var > 50)),
+                             var = as.name(pollutant)))
+            days$site <- Mean$site ## make sure all have same columns
+            days$date <- Mean$date
 
-            pm10.results <- Reduce(function(x, y, by = 'year') merge(x, y, by = 'year',
-                                                  all = TRUE), pm10.results)
+            pm10.results <- list(dataCapture, Mean, Min, Max, Median, maxDaily, rollMax8,
+                                 rollMax24, Percentile, days)
+
+            pm10.results <- Reduce(function(x, y) merge(x, y, by = c('site', 'year', 'date'),
+                                                        all = TRUE), pm10.results)
             pm10.results$pollutant <- "PM10"
             results <- pm10.results
             results
@@ -299,7 +237,7 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
             co.results <- list(dataCapture, Mean, Min, Max, Median, maxDaily, rollMax8, rollMax24,
                                Percentile)
             co.results <- Reduce(function(x, y, by = 'year') merge(x, y, by = 'year',
-                                                all = TRUE), co.results)
+                                                    all = TRUE), co.results)
             co.results$pollutant <- "CO"
             results <- co.results
             results
@@ -313,7 +251,7 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
             results <- list(dataCapture, Mean, Min, Max, Median, maxDaily, rollMax8, rollMax24,
                             Percentile)
             results <- Reduce(function(x, y, by = 'year') merge(x, y, by = 'year',
-                                             all = TRUE), results)
+                                                 all = TRUE), results)
             results$pollutant <- pollutant
             results <- results
 
@@ -325,27 +263,32 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
 
     ## function to go through sites
 
-    bySite <- function (mydata, pollutant, ...) {
+    bySite <- function (mydata, pollutant, data.thresh = data.thresh,
+                        percentile = percentile, ...) {
 
         ## dates should be unique; issue warning if not
         if (any(duplicated(mydata$date))) warning ("Duplicate dates detected - more than one site?",
                                                    call. = FALSE)
 
 
-        results <- lapply(pollutant, function (x) calcStats(mydata = mydata, pollutant = x ,...))
+        results <- lapply(pollutant, function (x) calcStats(mydata = mydata, pollutant = x ,
+                                                            data.thresh = data.thresh,
+                                                            percentile = percentile, ...))
 
 
-        results <- do.call (rbind.fill, results)
+        results <- rbind_all(results)
         results$year <- as.numeric(results$year)
         results
     }
 
-    results <- ddply(mydata, .(site), bySite, pollutant = pollutant,
-                     data.thresh = data.thresh,
-                     percentile = percentile,...)
+    
+    results <- group_by(mydata, site) %>%
+      do(bySite(mydata, pollutant = pollutant, data.thresh = data.thresh,
+                percentile = percentile,...))
+
     ## order sensible
     results <- cbind(subset(results, select = c(site, pollutant)), subset(results,
-                                     select = -c(site, pollutant)))
+                                         select = -c(site, pollutant)))
     class(results$year) <- "integer"
 
     ## transpose if requested
@@ -365,3 +308,19 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
     results
 
 }
+
+
+AOT40 <- function(mydata, pollutant, ...) {
+    ## note the assumption is the O3 is in ug/m3
+    daylight <- NULL
+    
+    ## need daylight hours in growing season (April to September)
+    mydata <- selectByDate(mydata, month = 4:9)
+    mydata <- cutData(mydata, "daylight", ...)
+    mydata <- subset(mydata, daylight == "daylight")
+    AOT40 <- ifelse(mydata[[pollutant]] - 80 < 0 , 0, mydata[[pollutant]] - 80)
+    AOT40 <- sum(AOT40, na.rm = TRUE) * 0.50 ## for ppb
+    AOT40 <- data_frame(AOT40)
+    return(AOT40)
+}
+
