@@ -508,14 +508,14 @@ importKCL <- function(site = "my1", year = 2009, pollutant = "all", met = FALSE,
 
     thedata <- lapply(files, loadData)
 
-    thedata <- ldply(thedata, rbind.fill)
+    thedata <- plyr::ldply(thedata, bind_rows)
 
     if (is.null(thedata)) stop("No data to import - check site codes and year.", call. = FALSE)
 
     thedata$code <- thedata$site
 
     thedata$site <- factor(thedata$site, labels = site.name, levels = site)
-
+    
 
     ## change names
     names(thedata) <- tolower(names(thedata))
@@ -542,17 +542,17 @@ importKCL <- function(site = "my1", year = 2009, pollutant = "all", met = FALSE,
     ## rename PM volatile/non volatile components if present
 
     if ("pmfr" %in% names(thedata)) {
-        thedata <- rename(thedata, c(pmfr = "v10"))
+        thedata <- rename_(thedata, v10 = "pmfr")
         thedata <- transform(thedata, v10 = -1 * v10)
     }
-
+    
     if ("p2fr" %in% names(thedata)) {
-        thedata <- rename(thedata, c(p2fr = "v2.5"))
+        thedata <- rename_(thedata, v2.5 = "p2fr")
         thedata <- transform(thedata, v2.5 = -1 * v2.5)
     }
 
-    if ("pmfb" %in% names(thedata)) thedata <- rename(thedata, c(pmfb = "nv10"))
-    if ("p2fb" %in% names(thedata)) thedata <- rename(thedata, c(p2fb = "nv2.5"))
+    if ("pmfb" %in% names(thedata)) thedata <- rename_(thedata, nv10 = "pmfb")
+    if ("p2fb" %in% names(thedata)) thedata <- rename_(thedata, nv2.5 = "p2fb")
 
 
     if (units != "mass")  {
