@@ -490,7 +490,7 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
         if (missing(group)) poll1 <- pollutant[1]; poll2 <- pollutant[2]
         if (!missing(group)) poll1 <- levels(mydata$variable)[1]; poll2 <- levels(mydata$variable)[2]
     }
-
+    
     ## number of columns for key
     if (missing(key.columns)) key.columns <- npol
 
@@ -515,12 +515,13 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
         
     } else {
 
-        data.hour <- ldply(conf.int, proc, mydata, vars = "hour", pollutant, type, B = B,
+        data.hour <- plyr::ldply(conf.int, proc, mydata, vars = "hour", pollutant, type, B = B,
                            statistic = statistic)
     }
 
 
-    if (normalise) data.hour <-  ddply(data.hour, .(variable), divide.by.mean)
+   if (normalise) data.hour <-  group_by(data.hour, variable) %>%
+      do(divide.by.mean(.))
 
     if (is.null(xlab[2]) | is.na(xlab[2])) xlab[2] <- "hour"
 
@@ -556,7 +557,7 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
                         panel.superpose(x, y, ...,
                                         panel.groups = function(x, y, col.line, type,
                                             group.number, subscripts,...) {
-
+                                            
                                             if (difference) panel.abline(h = 0, lty = 5)
                                             ## plot once
                                             id <- which(data.hour$ci[subscripts] == data.hour$ci[1])
@@ -585,12 +586,13 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
         data.weekday <- errorDiff(mydata, vars = "wkday", type = type, poll1 =poll1,
                                   poll2 = poll2, B = B, conf.int = conf.int)
     } else {
-        data.weekday <- ldply(conf.int, proc, mydata, vars = "wkday", pollutant, type, B = B,
+        data.weekday <- plyr::ldply(conf.int, proc, mydata, vars = "wkday", pollutant, type, B = B,
                               statistic = statistic)
     }
 
-    if (normalise) data.weekday <-  ddply(data.weekday, .(variable), divide.by.mean)
-
+    if (normalise) data.weekday <-  group_by(data.weekday, variable) %>%
+      do(divide.by.mean(.))
+    
     data.weekday$wkday <- ordered(data.weekday$wkday, levels = day.ord)
 
     data.weekday$wkday <- as.numeric(as.factor(data.weekday$wkday))
@@ -626,7 +628,7 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
                                             id <- which(data.weekday$ci[subscripts] == data.weekday$ci[1])
                                             panel.xyplot(x[id], y[id], type = "l",
                                                          col.line = myColors[group.number],...)
-
+                                            
                                             if (ci) {mkrect(data.weekday[subscripts, ], x = "wkday",
                                                             y = "Mean", group.number, myColors, alpha)}
                                             ## refrence line(s)
@@ -634,8 +636,8 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
                                         }
                                         )
                     }
-                    )
-
+                    
+)
     ## reset for extra.args
     xy.args <- listUpdate(xy.args, extra.args)
 
@@ -648,11 +650,13 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
         data.month <- errorDiff(mydata, vars = "mnth", type = type, poll1 = poll1,
                                 poll2 = poll2, B = B, conf.int = conf.int)
     } else {
-        data.month <- ldply(conf.int, proc, mydata, vars = "mnth", pollutant, type, B = B,
+        data.month <- plyr::ldply(conf.int, proc, mydata, vars = "mnth", pollutant, type, B = B,
                             statistic = statistic)
     }
 
-    if (normalise) data.month <-  ddply(data.month, .(variable), divide.by.mean)
+    if (normalise) data.month <-  group_by(data.month, variable) %>%
+      do(divide.by.mean(.))
+    
 
     if (is.null(xlab[3]) | is.na(xlab[3])) xlab[3] <- "month"
 
@@ -714,12 +718,13 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
         data.day.hour <- errorDiff(mydata, vars = "day.hour", type = type, poll1 = poll1,
                                    poll2 = poll2, B = B, conf.int = conf.int)
     } else {
-        data.day.hour <- ldply(conf.int, proc, mydata, vars = "day.hour", pollutant, type, B = B,
-                               statistic = statistic)
+        data.day.hour <- plyr::ldply(conf.int, proc, mydata, vars = "day.hour", pollutant,
+                                     type, B = B, statistic = statistic)
     }
 
-    if (normalise) data.day.hour <-  ddply(data.day.hour, .(variable), divide.by.mean)
-
+    if (normalise) data.day.hour <-  group_by(data.day.hour, variable) %>%
+      do(divide.by.mean(.))
+   
     ids <- which(is.na(data.day.hour$Lower)) ## missing Lower ci, set to mean
 
     data.day.hour$Lower[ids] <-  data.day.hour$Mean[ids]
@@ -894,7 +899,7 @@ proc <- function(conf.int = conf.int, mydata, vars = "day.hour", pollutant, type
         data2 <- data.frame(subset(data2, select = -value), data2$value)
     }
 
-    if (length(pollutant) > 1 & "wd" %in% pollutant) data2 <- rbind.fill(data1, data2)
+    if (length(pollutant) > 1 & "wd" %in% pollutant) data2 <- bind_rows(data1, data2)
 
     if (!"wd" %in% pollutant) data2 <- data1
 
@@ -947,8 +952,11 @@ errorDiff <- function(mydata, vars = "day.hour", poll1, poll2, type, B = B,
     if (vars == "day.hour") splits <- c("hour", "wkday", type)
     if (vars == "wkday") splits <- c("wkday", type)
     if (vars == "mnth") splits <- c("mnth", type)
-
-    res <- ddply(mydata, splits, bootMeanDiff, x = poll1, y = poll2, B = B)
+    
+    ## warnings from dplyr seem harmless FIXME
+    res <- suppressWarnings(group_by_(mydata, .dots = splits) %>%
+      do(bootMeanDiff(., x = poll1, y = poll2, B = B)))
+  
     res$ci <- conf.int[1]
     res
 }
@@ -966,7 +974,7 @@ median.hilow <- function (x, conf.int = 0.95, na.rm = TRUE, ...) {
 mkpoly <- function(dat, x = "hour", y = "Mean", group.number, myColors, alpha) {
     len <- length(unique(dat$ci)) ## number of confidence intervals to consider
     ci <- sort(unique(dat$ci))
-
+    
     fac <- 2
 
     if (len == 1L) id1 <- which(dat$ci == ci[1]) ## ids of higher band
@@ -977,10 +985,10 @@ mkpoly <- function(dat, x = "hour", y = "Mean", group.number, myColors, alpha) {
         fac <- 1
     }
 
-    poly.na(dat[id1, x], dat$Lower[id1], dat[id1, x], dat$Upper[id1],
+    poly.na(dat[[x]][id1], dat$Lower[id1], dat[[x]][id1], dat$Upper[id1],
             group.number, myColors, alpha = fac * alpha / 2)
 
-    if (len == 2L) poly.na(dat[id2, x], dat$Lower[id2], dat[id2, x], dat$Upper[id2],
+    if (len == 2L) poly.na(dat[[x]][id2], dat$Lower[id2], dat[[x]][id2], dat$Upper[id2],
             group.number, myColors, alpha = alpha)
 }
 
@@ -998,11 +1006,11 @@ mkrect <- function(dat, x = "wkday", y = "Mean", group.number, myColors, alpha)
         fac <- 1
     }
 
-    panel.rect(dat[id1, x] - 0.15 * fac, dat$Lower[id1], dat[id1, x] + 0.15 * fac,
+    panel.rect(dat[[x]][id1] - 0.15 * fac, dat$Lower[id1], dat[[x]][id1] + 0.15 * fac,
                dat$Upper[id1], fill = myColors[group.number],
                border = NA, alpha = fac * alpha / 2)
 
-    if (len == 2L) panel.rect(dat[id2, x] - 0.3, dat$Lower[id2], dat[id2, x] + 0.3,
+    if (len == 2L) panel.rect(dat[[x]][id2] - 0.3, dat$Lower[id2], dat[[x]][id2] + 0.3,
             dat$Upper[id2], fill = myColors[group.number],
             border = NA, alpha = alpha)
 }
